@@ -6,4 +6,5 @@ class Command(BaseCommand):
     help = 'Sync subscriptions'
 
     def handle(self, *args, **options):
-        PaddleSubscription.sync()
+        PaddleSubscription.sync()  # sync default
+        PaddleSubscription.sync(state='deleted')  # also sync deleted
